==> haskell-foldl-1.4.5-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.4.5
id: foldl-1.4.5-4YhpVFKmYXlEm1wSCICJmO
key: foldl-1.4.5-4YhpVFKmYXlEm1wSCICJmO
license: BSD-3-Clause
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
abi: b17b5fb9d5ffbf138bbf5af4532e563a
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl
hidden-modules: Control.Foldl.Optics Control.Foldl.Internal
import-dirs: /usr/lib/ghc-8.6.2/site-local/foldl-1.4.5
library-dirs: /usr/lib/ghc-8.6.2/site-local/foldl-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/foldl-1.4.5
hs-libraries: HSfoldl-1.4.5-4YhpVFKmYXlEm1wSCICJmO
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    comonad-5.0.4-LBTE5MzQHFTCR2pjCvdKVj containers-0.6.0.1
    contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mwc-random-0.14.0.0-68wICCEMHt12whMecqQzGM
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    profunctors-5.3-3ZUOvQmFZbaJi6Rfb5qOvJ
    semigroupoids-5.3.1-LU4mu95nnXv19zCyIHXywi text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
    vector-builder-0.3.6-1syingLJoc0ChHAGvxfMh
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.5-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.4.5
id: foldl-1.4.5-5SkHRn7UUzwKTzz1zwRwk6
key: foldl-1.4.5-5SkHRn7UUzwKTzz1zwRwk6
license: BSD-3-Clause
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
abi: 31d1ee5174a2805f16b66d4abd754bd0
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl
hidden-modules: Control.Foldl.Optics Control.Foldl.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/foldl-1.4.5
library-dirs: /usr/lib/ghc-8.6.3/site-local/foldl-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/foldl-1.4.5
hs-libraries: HSfoldl-1.4.5-5SkHRn7UUzwKTzz1zwRwk6
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    comonad-5.0.4-7xZctC1NcW5KK0MwhK5BFG containers-0.6.0.1
    contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mwc-random-0.14.0.0-1LT9WEdM4DvCmAkSxqGCKr
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    profunctors-5.3-97iQKvmfNrRC2DVtvgWUHK
    semigroupoids-5.3.1-3v7umH7l71x7sUYBS0aazs text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vector-builder-0.3.6-CkDPAaZKJ8EHn1PTJOymE0
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
